package com.ruoyi.system.service.projectV2;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.system.domain.projectV2.Vo.ZsyzQktjDc;
import com.ruoyi.system.domain.projectV2.ZsyzQktj;

/**
 * 招商引资_情况月统计Service接口
 * 
 * @author ruoyi
 * @date 2023-03-10
 */
public interface IZsyzQktjService 
{
    /**
     * 查询招商引资_情况月统计
     * 
     * @param id 招商引资_情况月统计主键
     * @return 招商引资_情况月统计
     */
    public ZsyzQktj selectZsyzQktjById(Long id);

    /**
     * 查询招商引资_情况月统计列表
     * 
     * @param zsyzQktj 招商引资_情况月统计
     * @return 招商引资_情况月统计集合
     */
    public List<ZsyzQktj> selectZsyzQktjList(ZsyzQktj zsyzQktj);

    /**
     * 新增招商引资_情况月统计
     * 
     * @param zsyzQktj 招商引资_情况月统计
     * @return 结果
     */
    public AjaxResult insertZsyzQktj(ZsyzQktj zsyzQktj);

    /**
     * 修改招商引资_情况月统计
     * 
     * @param zsyzQktj 招商引资_情况月统计
     * @return 结果
     */
    public int updateZsyzQktj(ZsyzQktj zsyzQktj);

    /**
     * 批量删除招商引资_情况月统计
     * 
     * @param ids 需要删除的招商引资_情况月统计主键集合
     * @return 结果
     */
    public int deleteZsyzQktjByIds(Long[] ids);

    /**
     * 删除招商引资_情况月统计信息
     * 
     * @param id 招商引资_情况月统计主键
     * @return 结果
     */
    public int deleteZsyzQktjById(Long id);

    List<ZsyzQktjDc> selectZsyzQktjListTj(ZsyzQktj zsyzQktj);
}
